﻿using Esri.ArcGISRuntime.Geometry;
using Esri.ArcGISRuntime.Layers;
using Esri.ArcGISRuntime.Symbology;
using System;
using Windows.Devices.Geolocation;
using Windows.UI.Popups;
using Windows.UI.Xaml.Controls;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace NewSample
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
            MapLoad();
        }
        private async void MapLoad()
        {
            try
            {

                double Longitude;
                double Latitude;
                var map = new Esri.ArcGISRuntime.Controls.Map();
                var uri = new Uri("http://services.arcgisonline.com/arcgis/rest/services/World_Street_Map/MapServer");
                var baseLayer = new Esri.ArcGISRuntime.Layers.ArcGISTiledMapServiceLayer(uri);
                baseLayer.ID = "BaseMap";
                map.Layers.Add(baseLayer);
                var loc = new Geolocator();
                try
                {
                    loc.DesiredAccuracy = PositionAccuracy.High;
                    Geoposition pos = await loc.GetGeopositionAsync();
                    Latitude = Convert.ToDouble(pos.Coordinate.Point.Position.Latitude.ToString());
                    Longitude = Convert.ToDouble(pos.Coordinate.Point.Position.Longitude.ToString());
                }
                catch (Exception ex)
                {
                    Longitude = 76.883266;
                    Latitude = 8.533200;
                }
                MapPoint mapPoint = new Esri.ArcGISRuntime.Geometry.MapPoint(Longitude, Latitude, Esri.ArcGISRuntime.Geometry.SpatialReferences.Wgs84);
                //sets the initial view point and scale of zoom
                var initViewPoint = new Esri.ArcGISRuntime.Controls.ViewpointCenter();
                initViewPoint.X = Longitude;
                initViewPoint.Y = Latitude;
                initViewPoint.SpatialReferenceID = 4326;
                initViewPoint.Scale = 500;
                map.InitialViewpoint = initViewPoint;

                mapView.Map = map;

                //Adding Pushpin
                Uri pushpinUri;
                pushpinUri = new Uri("http://static.arcgis.com/images/Symbols/Basic/GreenStickpin.png");

                PictureMarkerSymbol pushpinPictureMarkerSymbol = new PictureMarkerSymbol { Angle = 30, Height = 50, Width = 50 };
                await pushpinPictureMarkerSymbol.SetSourceAsync(pushpinUri);
                SimpleRenderer mySimpleRenderer = new SimpleRenderer { Symbol = pushpinPictureMarkerSymbol };
                GraphicsLayer pushpinGraphicsLayer = new GraphicsLayer { Renderer = mySimpleRenderer };
                pushpinGraphicsLayer.Graphics.Add(new Graphic(mapPoint, pushpinPictureMarkerSymbol));

                //Adding tooltip
                TextSymbol tooltip;
                tooltip = new TextSymbol();
                Graphic txtGraphic = new Graphic(mapPoint, tooltip);
                tooltip.Text = string.Concat("Latitude :", Latitude, Environment.NewLine, "Longitude :", Longitude);
                tooltip.Font.FontSize = 20;
                tooltip.YOffset = mapPoint.Y;
                pushpinGraphicsLayer.Graphics.Add(txtGraphic);
                this.mapView.Map.Layers.Add(pushpinGraphicsLayer);
                

            }
            catch (Exception ex)
            {
                MessageDialog msg = new MessageDialog("Exception occured"+ex);
                await msg.ShowAsync();
                
            }


        }

        //private void Button_Click(object sender, Windows.UI.Xaml.RoutedEventArgs e)
        //{
        //    MapLoad();
        //}
    }
}
